Skip to main content Crate healpix Copy item path Source pub use coords::LonLat ;bmoc checked Checked free functions; all of these assert a valid depth before delegating to their corresponding unchecked function. coords Longitude and latitude coordinate utilities coverage dir Direction enumerations. geo Geodesic operations for converting between longitude/latitude and azimuth/distance. neighbor Functions relating to the neighboring edges. proj sph_geom Module containing spherical geometry structures and methods like 3D vectors,
polygon or cone on the unit sphere… unchecked Unchecked free functions, these are called by implementations and the checked functions zoc Directly Taken from healpix’s nested::zordercurve. Layer Defines an HEALPix layer in the NESTED scheme.
A layer is simply an utility structure containing all constants and methods related
to a given depth. MAX_DEPTH Constant = 29, i.e. the largest possible depth we can store on a signed positive long
(4 bits for base cells + 2 bits per depth + 2 remaining bits (1 use in the unique notation). NSIDE_MAX Constant = nside(29), i.e. the largest possible nside available when we store HEALPix hash
on a u64. ONE_OVER_TRANSITION_Z Inverse of the limit on |z|=|sin(lat)| between the equatorial region and the polar caps.
Equals 1/(2/3) = 1.5, see Eq. (1) in Gorsky2005. TRANSITION_LATITUDE Limit on the latitude (in radians) between the equatorial region and the polar caps.
Equals asin(2/3) = 0.7297276562269663 radians ~= 41,81 degrees.
Written $\theta_X$ in Calabretta2007. TRANSITION_Z Limit on |z|=|sin(lat)| between the equatorial region and the polar caps.
Equals 2/3, see Eq. (1) in Gorsky2005. assert_valid_depth from_uniq Returns the depth and the hash number from the uniq representation.
Inverse operation of to_uniq . from_uniq_ivoa Returns the depth and the hash number from the uniq representation.
Inverse operation of to_uniq . get Get the Layer corresponding to the given depth. is_valid_depth to_range x_mask mask …010101 xy_mask mask …111111 y_mask mask …101010